@@ -1,6 +1,6 @@
 package Fey::Object::Table;
-BEGIN {
-  $Fey::Object::Table::VERSION = '0.43';
+{
+  $Fey::Object::Table::VERSION = '0.44';
 }
 
 use strict;
@@ -587,7 +587,7 @@ Fey::Object::Table - Base class for table-based objects
 
 =head1 VERSION
 
-version 0.43
+version 0.44
 
 =head1 SYNOPSIS
 
@@ -785,9 +785,8 @@ This method is expected to create a C<SELECT> statement and then pass
 the statement and bind parameters to C<< $object->_get_column_values()
 >>.
 
-On success, this method should simply return. If it fails, it should
-throw a L<Fey::Exception::NoSuchRow> exception. See
-L<Fey::ORM::Exceptions> for details.
+On success, this method should simply return. If it fails, it should throw a
+Fey::Exception::NoSuchRow exception. See L<Fey::ORM::Exceptions> for details.
 
 =head2 $object->_get_column_values( $select, $bind_params )
 
